@@ -22,6 +22,8 @@
 #include <mach/mach_time.h>
 #endif
 
+#include "taskflow/taskflow.hpp"
+
 #include <fstream>
 #include <sstream>
 #include "json.hpp"
@@ -95,7 +97,7 @@ double FirebaseImpl::GetTime()
 bool FirebaseImpl::ProcessEvents(int msec)
 {
     Sleep(msec);
-    return false;
+    return true;
 }
 
 void FirebaseImpl::Init(bool analytics, bool messaging, bool remoteConfig, bool firestore)
@@ -105,38 +107,72 @@ void FirebaseImpl::Init(bool analytics, bool messaging, bool remoteConfig, bool
 	m_isRemoteConfig = remoteConfig;
 	m_isFirestore = firestore;
 
-    // app
-    Firebase::firebase_app = ::firebase::App::GetInstance();
-    if(Firebase::firebase_app == nullptr)
-    {
-        Firebase::firebase_app = ::firebase::App::Create();    
-    }
+	tf::Executor executor;
+	tf::Taskflow taskflow("simple");
 
-	// analytics
-	if (m_isAnalytics)
+	auto fb_app = taskflow.emplace([]()
 	{
-		AnalyticsInit();
-	}
+		// app
+		Firebase::firebase_app = ::firebase::App::GetInstance();
+		if (Firebase::firebase_app == nullptr)
+		{
+			Firebase::firebase_app = ::firebase::App::Create();
+		}
+	});
 
-	// messaging
-	if (m_isMessaging)
+	auto fb_analytics = taskflow.emplace([this]()
 	{
-		MessagingInit();
-	}
+		// analytics
+		if (m_isAnalytics)
+		{
+			AnalyticsInit();
+		}
+	});
 
-	// remote config
-	if (m_isRemoteConfig)
+	auto fb_messaging = taskflow.emplace([this]()
 	{
-		RemoteConfigInit();
-	}
+		// messaging
+		if (m_isMessaging)
+		{
+			MessagingInit();
+		}
+	});
 
-	// firestore
-	if (m_isFirestore)
+	auto fb_remoteConfig = taskflow.emplace([this]()
 	{
-		FirestoreInit();
-	}
+		// remote config
+		if (m_isRemoteConfig)
+		{
+			RemoteConfigInit();
+			RemoteConfigFetch();
+		}
+	});
 
-    m_isReady = true;
+	auto fb_firestore = taskflow.emplace([this]()
+	{
+		// firestore
+		if (m_isFirestore)
+		{
+			FirestoreInit();
+		}
+	});
+
+	auto fb_end = taskflow.emplace([this]()
+	{
+		m_isReady = true;
+	});
+
+	fb_app.precede(fb_analytics);
+	fb_app.precede(fb_messaging);
+	fb_app.precede(fb_remoteConfig);
+	fb_app.precede(fb_firestore);
+
+	fb_analytics.precede(fb_end);
+	fb_messaging.precede(fb_end);
+	fb_remoteConfig.precede(fb_end);
+	fb_firestore.precede(fb_end);
+
+	executor.run(taskflow).wait();
 }
 
 void FirebaseImpl::Release()
@@ -306,6 +342,14 @@ void FirebaseImpl::RemoteConfigRelease()
 }
 
 void FirebaseImpl::RemoteConfigFetchAll()
+{
+	if (m_isReady)
+	{
+		RemoteConfigFetch();
+	}
+}
+
+void FirebaseImpl::RemoteConfigFetch()
 {
 	auto future_result = firebase::remote_config::Fetch(0);
 	while (future_result.status() == firebase::kFutureStatusPending) {
