@@ -2,6 +2,8 @@
 
 
 FirebaseMLKitImpl::FirebaseMLKitImpl()
+	: contourPoints(nullptr)
+	, rgbData(nullptr)
 {
 }
 
@@ -11,6 +13,10 @@ FirebaseMLKitImpl::~FirebaseMLKitImpl()
 
 void FirebaseMLKitImpl::Init(int mode)
 {
+	if (contourPoints == nullptr)
+	{
+		contourPoints = new float[allContourPointsSize * 2];
+	}
 }
 
 void FirebaseMLKitImpl::Release()
@@ -38,15 +44,25 @@ float* FirebaseMLKitImpl::GetContours(int& size)
 
 uint8_t* FirebaseMLKitImpl::GetCameraData()
 {
-	return {};
+	int h = GetCameraHeight();
+	int w = GetCameraWidth();
+
+	if (rgbData == nullptr)
+	{
+		size_t len = (size_t)w * h * 3;
+		rgbData = new uint8_t[len];
+		memset(rgbData, 0, len);
+	}
+
+	return rgbData;
 }
 
 int FirebaseMLKitImpl::GetCameraWidth()
 {
-	return 0;
+	return 360;
 }
 
 int FirebaseMLKitImpl::GetCameraHeight()
 {
-	return 0;
+	return 480;
 }
\ No newline at end of file
